Crate meowg

Crate meowg 

Trivial terminal loggers with Catppuccin colour palette.

Usage

Set up your preferred Catppuccin flavour Latte, Frappe, Macchiato or Mocha through its associated install function or manually via log::set_logger.

The install function sets the maximum log level to log::LevelFilter::Trace for debug builds or log::LevelFilter::Info for release builds.

The logger may then be used through the standard log facilities.

These loggers write to standard error, are not configurable and do not log anything beyond the message itself. They will however adapt to a terminal’s capabilities thanks to anstream.

They are intended to be used for development alongside more featureful loggers like systemd-journal-logger.

Example

use log::warn;

meowg::Mocha::install().unwrap();
warn!("This is your final warning");

Structs

Frappe
Logger based on the Catppuccin Frappe flavour.
Latte
Logger based on the Catppuccin Latte flavour.
Macchiato
Logger based on the Catppuccin Macchiato flavour.
Mocha
Logger based on the Catppuccin Mocha flavour.